- TestReport

# Test Report:

## Summary

START AT | 2019-03-08 22:18:08
DURATION | 63.191 seconds
PLATFORM | zybats 2.0.2.4 | CPython 3.7.2 | Windows-10-10.0.17134-SP0
STAT | TESTCASES (success/fail) | TESTSTEPS (success/fail/error/skip)
--- | --- | ---
total (details) => | 2 (0/2) | 6 (0/0/6/0)

## Details

### call testcase demo one.

TOTAL: 3 | SUCCESS: 0 | FAILED: 0 | ERROR: 3 | SKIPPED: 0
Status | Name | Response Time | Detail
--- | --- | --- | ---
error | call api def example | 21025.75 ms | log-1 ## Request and Response data × ### Name: call api def example ### Request:
url | http://172.23.136.190:8080/api/getTokenId
method | POST
headers | Content-Type: application/json
json | {'user_agent': 'testcase_user_agent', 'device_sn': 'testsuit_global_sign', 'os_platform': 'testcase_os', 'app_version': 'testcase_version'}
verify | True
timeout | 120
### Response:
status_code | N/A
headers |
encoding | None
content_type |
### Validators:
check | comparator | expect value | actual value
--- | --- | --- | ---
### Statistics:
content_size(bytes) | 0
response_time(ms) | 21025.75
elapsed(ms) | 0.0
traceback ## Traceback Message ×
    Traceback (most recent call last):
    TimeoutError: [WinError 10060] 由于连接方在一段时间后没有正确答复或连接的主机没有反应，连接尝试失败。

    During handling of the above exception, another exception occurred:

    Traceback (most recent call last):
    urllib3.exceptions.NewConnectionError: <urllib3.connection.HTTPConnection object at 0x000001F833D887B8>: Failed to establish a new connection: [WinError 10060] 由于连接方在一段时间后没有正确答复或连接的主机没有反应，连接尝试失败。

    During handling of the above exception, another exception occurred:

    Traceback (most recent call last):
    urllib3.exceptions.MaxRetryError: HTTPConnectionPool(host='172.23.136.190', port=8080): Max retries exceeded with url: /api/getTokenId (Caused by NewConnectionError('<urllib3.connection.HTTPConnection object at 0x000001F833D887B8>: Failed to establish a new connection: [WinError 10060] 由于连接方在一段时间后没有正确答复或连接的主机没有反应，连接尝试失败。'))

    During handling of the above exception, another exception occurred:

    Traceback (most recent call last):
    requests.exceptions.ConnectionError: HTTPConnectionPool(host='172.23.136.190', port=8080): Max retries exceeded with url: /api/getTokenId (Caused by NewConnectionError('<urllib3.connection.HTTPConnection object at 0x000001F833D887B8>: Failed to establish a new connection: [WinError 10060] 由于连接方在一段时间后没有正确答复或连接的主机没有反应，连接尝试失败。'))
error | use redis ext api example | N/A ms | log-1 ## Request and Response data × ### Name: ### Request:
url | N/A
method | N/A
headers |
### Response:
status_code | N/A
headers |
encoding | None
content_type |
### Validators:
check | comparator | expect value | actual value
--- | --- | --- | ---
### Statistics:
content_size(bytes) | N/A
response_time(ms) | N/A
elapsed(ms) | N/A
traceback ## Traceback Message ×
    Traceback (most recent call last):
    KeyError: 'id'

    During handling of the above exception, another exception occurred:

    Traceback (most recent call last):
    zybats.exceptions.VariableNotFound: id is not found.
error | use mysql ext api example | N/A ms | log-1 ## Request and Response data × ### Name: ### Request:
url | N/A
method | N/A
headers |
### Response:
status_code | N/A
headers |
encoding | None
content_type |
### Validators:
check | comparator | expect value | actual value
--- | --- | --- | ---
### Statistics:
content_size(bytes) | N/A
response_time(ms) | N/A
elapsed(ms) | N/A
traceback ## Traceback Message ×
    Traceback (most recent call last):
    KeyError: 'id'

    During handling of the above exception, another exception occurred:

    Traceback (most recent call last):
    zybats.exceptions.VariableNotFound: id is not found.

### call testcase demo two.

TOTAL: 3 | SUCCESS: 0 | FAILED: 0 | ERROR: 3 | SKIPPED: 0
Status | Name | Response Time | Detail
--- | --- | --- | ---
error | call api def example | 21004.93 ms | log-1 ## Request and Response data × ### Name: call api def example ### Request:
url | http://172.23.136.190:8080/api/getTokenId
method | POST
headers | Content-Type: application/json
json | {'user_agent': 'testcase_user_agent', 'device_sn': 'testsuit_global_sign', 'os_platform': 'testcase_os', 'app_version': 'testcase_version'}
verify | True
timeout | 120
### Response:
status_code | N/A
headers |
encoding | None
content_type |
### Validators:
check | comparator | expect value | actual value
--- | --- | --- | ---
### Statistics:
content_size(bytes) | 0
response_time(ms) | 21004.93
elapsed(ms) | 0.0
traceback ## Traceback Message ×
    Traceback (most recent call last):
    TimeoutError: [WinError 10060] 由于连接方在一段时间后没有正确答复或连接的主机没有反应，连接尝试失败。

    During handling of the above exception, another exception occurred:

    Traceback (most recent call last):
    urllib3.exceptions.NewConnectionError: <urllib3.connection.HTTPConnection object at 0x000001F833D79B00>: Failed to establish a new connection: [WinError 10060] 由于连接方在一段时间后没有正确答复或连接的主机没有反应，连接尝试失败。

    During handling of the above exception, another exception occurred:

    Traceback (most recent call last):
    urllib3.exceptions.MaxRetryError: HTTPConnectionPool(host='172.23.136.190', port=8080): Max retries exceeded with url: /api/getTokenId (Caused by NewConnectionError('<urllib3.connection.HTTPConnection object at 0x000001F833D79B00>: Failed to establish a new connection: [WinError 10060] 由于连接方在一段时间后没有正确答复或连接的主机没有反应，连接尝试失败。'))

    During handling of the above exception, another exception occurred:

    Traceback (most recent call last):
    requests.exceptions.ConnectionError: HTTPConnectionPool(host='172.23.136.190', port=8080): Max retries exceeded with url: /api/getTokenId (Caused by NewConnectionError('<urllib3.connection.HTTPConnection object at 0x000001F833D79B00>: Failed to establish a new connection: [WinError 10060] 由于连接方在一段时间后没有正确答复或连接的主机没有反应，连接尝试失败。'))
error | use redis ext api example | N/A ms | log-1 ## Request and Response data × ### Name: ### Request:
url | N/A
method | N/A
headers |
### Response:
status_code | N/A
headers |
encoding | None
content_type |
### Validators:
check | comparator | expect value | actual value
--- | --- | --- | ---
### Statistics:
content_size(bytes) | N/A
response_time(ms) | N/A
elapsed(ms) | N/A
traceback ## Traceback Message ×
    Traceback (most recent call last):
    KeyError: 'id'

    During handling of the above exception, another exception occurred:

    Traceback (most recent call last):
    zybats.exceptions.VariableNotFound: id is not found.
error | use mysql ext api example | N/A ms | log-1 ## Request and Response data × ### Name: ### Request:
url | N/A
method | N/A
headers |
### Response:
status_code | N/A
headers |
encoding | None
content_type |
### Validators:
check | comparator | expect value | actual value
--- | --- | --- | ---
### Statistics:
content_size(bytes) | N/A
response_time(ms) | N/A
elapsed(ms) | N/A
traceback ## Traceback Message ×
    Traceback (most recent call last):
    KeyError: 'id'

    During handling of the above exception, another exception occurred:

    Traceback (most recent call last):
    zybats.exceptions.VariableNotFound: id is not found.